Page 20 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 20

Home

    Acceptance of the worship of heathen deities often
    led to grossly immoral practices, even to human sacrifice
    as in the worship of Molech. It is a sad commentary that
    even Solomon fell into idol worship in his old age (I

    Kings 11:1-8).

    After the death of Solomon the kingdom was divided
    into the Northern Kingdom of ten tribes (Israel) and the
    Southern Kingdom of two tribes (Judah). Immediately,
    Israel rejected the Law of Moses and turned to worship
    of the Golden Calf, an Egyptian deity. The Northern
    Kingdom lasted about 200 years until it was destroyed
    by Assyria in 721 B.C. Every one of its 19 kings
    followed the worship of the Golden Calf.

    Judah, the Southern Kingdom, lasted slightly more
    than 300 years, and as was noted previously, was
    destroyed by Babylon about 600 B.C. Most of its Kings
    also worshiped idols. Only a few revered the Law of

    Moses.

    rejection of the Law of Moses is attested to in the
    writings of Old Testament prophets. Jeremiah denounced
    the existence of such a movement in his day. This is

    And the Lord said unto me, A conspiracy is found
    among the men of Judah, and among the inhabitants of
    Jerusalem.

    15

    Ancient Oral Traditions

    the deities of the heathen nations around them.

    That there was indeed a secret movement behind the

    recorded in Jeremiah 11:9-10: